/*jslint nomen: true, indent: 4*/
/*global define,window,preview*/

define([
    'testsuite/qunit',
    'jquery',
    './preview-view',
    './file-model',
    './item-collection',
    './folder-model',
    '$ready!'
], function (QUnit, $, PreviewView, FileModel, ItemCollection, FolderModel) {
    'use strict';

    QUnit.module('de_epages/mediagallery/filemanager/preview-view', {
        setup: function () {
            var filemanager = $('<div class="filemanager" />').appendTo('#qunit-fixture'),
                model = new FileModel({
                    "width": 1000,
                    "extension": ".jpg",
                    "name": "epages.jpg",
                    "path": "/epages.jpg",
                    "height": 237,
                    "directory": "/MediaGallery",
                    "modified": 1200994146,
                    "size": 67089,
                    "fullpath": ".:/de_epages/mediagallery/filemanager/epages.jpg",
                    "selectable": 0,
                    "mimetype": "image/jpg",
                    "metadata" : {
                        "type" : "MediaGallery"
                    }
                }),
                collection = new ItemCollection();

            collection.push(model);
            window.preview = new PreviewView({collection: collection});
            filemanager.append(preview.render().el);

            preview.on('deleteItems', function () {
                QUnit.ok(true, 'Trigger event deleteItems on preview view');
            });

        },
        teardown: function () {
            $('.ep-mediagallery-preview').remove();

            QUnit.strictEqual(
                $('.ep-mediagallery-preview').length,
                0,
                'Remove preview view from filemanager container'
            );
        }
    });

    QUnit.test('view methods', function () {
        $.each(['initialize', 'render', 'clear', 'triggerDeleteItems', 'downloadItem'], function (i, method) {
            QUnit.strictEqual(
                $.isFunction(preview[method]),
                true,
                method + ' is a method of preview view'
            );
        });
    });

    QUnit.test('view functionality', function () {
        var model = new FolderModel({
                "files": [],
                "children": [],
                "metadata": {
                    "displayname": "neu",
                    "type": "MediaGallery",
                    "path": "/neu"
                },
                "data": "neu",
                "state": null
            });

        QUnit.strictEqual(
            $('.ep-mediagallery-preview img').length,
            1,
            'epages.jpg is displayed on preview view'
        );

        $('.ep-mediagallery-deleteItem').trigger('click');

        preview.clear();

        QUnit.strictEqual(
            $('.ep-mediagallery-preview img').length,
            0,
            'Preview view was cleared'
        );

        preview.collection.push(model);
        preview.render();

        QUnit.strictEqual(
            $('.ep-mediagallery-preview img').length,
            1,
            'folder is displayed on preview view'
        );

    });

});